@@ -1,3 +1,4 @@
+use crate::ui::print_root_header;
 use colored::Colorize;
 use content_inspector::{inspect, ContentType};
 use pad::{Alignment, PadStr};
@@ -7,6 +8,7 @@ use walkdir::{DirEntry, WalkDir};
 pub struct Executable {
     pub short_name: String,
     pub path: PathBuf,
+    pub absolute_path: PathBuf,
 }
 
 pub struct Executables {
@@ -26,16 +28,16 @@ impl Executables {
                 Err(_) => panic!("Couldn't read dir!"),
             };
             if !entry.file_type().is_dir() && is_executable(&entry) && !is_binary(&entry) {
+                let path = entry.into_path();
+                let absolute_path = std::fs::canonicalize(&path).unwrap();
                 executables.push(Executable {
-                    short_name: entry.file_name().to_string_lossy().to_string(),
-                    path: entry.into_path(),
+                    short_name: path.file_name().unwrap().to_string_lossy().to_string(),
+                    path,
+                    absolute_path,
                 })
             }
         }
-        Self {
-            // root: root.to_string(),
-            executables,
-        }
+        Self { executables }
     }
 
     pub fn get(&self, name: &str) -> Option<&Executable> {
@@ -47,7 +49,7 @@ impl Executables {
     /// Pretty-prints the executables we found on the path, so the
     /// user can select one to run.
     pub fn pretty_print(&self) {
-        println!("{}", "lk: ./".on_blue());
+        print_root_header();
         // Get the longest executable name
         const INDENT: usize = 2;
         let padding = self
